=== modified file 'bzrlib/lazy_import.py'
--- bzrlib/lazy_import.py	2006-09-12 19:07:27 +0000
+++ bzrlib/lazy_import.py	2006-09-13 02:44:23 +0000
@@ -19,9 +19,6 @@
 This includes waiting to import a module until it is actually used.
 """
 
-import re
-import sys
-
 from bzrlib import (
     errors,
     )

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2006-09-08 18:52:17 +0000
+++ bzrlib/osutils.py	2006-09-13 02:44:23 +0000
@@ -17,6 +17,16 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from cStringIO import StringIO
+import os
+import re
+import stat
+from stat import (S_ISREG, S_ISDIR, S_ISLNK, ST_MODE, ST_SIZE,
+                  S_ISCHR, S_ISBLK, S_ISFIFO, S_ISSOCK)
+import sys
+import time
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 import errno
 from ntpath import (abspath as _nt_abspath,
                     join as _nt_join,
@@ -24,32 +34,35 @@
                     realpath as _nt_realpath,
                     splitdrive as _nt_splitdrive,
                     )
-import os
-from os import listdir
 import posixpath
-import re
 import sha
 import shutil
-from shutil import copyfile
-import stat
-from stat import (S_ISREG, S_ISDIR, S_ISLNK, ST_MODE, ST_SIZE,
-                  S_ISCHR, S_ISBLK, S_ISFIFO, S_ISSOCK)
+from shutil import (
+    rmtree,
+    )
 import string
-import sys
-import time
-import types
 import tempfile
+from tempfile import (
+    mkdtemp,
+    )
 import unicodedata
+""")
 
 import bzrlib
-from bzrlib.errors import (BzrError,
-                           BzrBadParameterNotUnicode,
-                           NoSuchFile,
-                           PathNotChild,
-                           IllegalPath,
-                           )
-from bzrlib.symbol_versioning import (deprecated_function, 
-        zero_nine)
+from bzrlib import (
+    errors,
+    )
+from bzrlib.errors import (
+    BzrError,
+    BzrBadParameterNotUnicode,
+    NoSuchFile,
+    PathNotChild,
+    IllegalPath,
+    )
+from bzrlib.symbol_versioning import (
+    deprecated_function,
+    zero_nine,
+    )
 from bzrlib.trace import mutter
 
 
@@ -122,7 +135,7 @@
         return _mapper(_lstat(f).st_mode)
     except OSError, e:
         if getattr(e, 'errno', None) == errno.ENOENT:
-            raise bzrlib.errors.NoSuchFile(f)
+            raise errors.NoSuchFile(f)
         raise
 
 
@@ -302,11 +315,12 @@
 pathjoin = os.path.join
 normpath = os.path.normpath
 getcwd = os.getcwdu
-mkdtemp = tempfile.mkdtemp
 rename = os.rename
 dirname = os.path.dirname
 basename = os.path.basename
-rmtree = shutil.rmtree
+# These were already imported into local scope
+# mkdtemp = tempfile.mkdtemp
+# rmtree = shutil.rmtree
 
 MIN_ABS_PATHLENGTH = 1
 
@@ -330,7 +344,7 @@
         if function in (os.remove, os.rmdir) \
             and type_ == OSError \
             and value.errno == errno.EACCES:
-            bzrlib.osutils.make_writable(path)
+            make_writable(path)
             function(path)
         else:
             raise
@@ -440,19 +454,6 @@
     
     The empty string as a dir name is taken as top-of-tree and matches 
     everything.
-    
-    >>> is_inside('src', pathjoin('src', 'foo.c'))
-    True
-    >>> is_inside('src', 'srccontrol')
-    False
-    >>> is_inside('src', pathjoin('src', 'a', 'a', 'a', 'foo.c'))
-    True
-    >>> is_inside('foo.c', 'foo.c')
-    True
-    >>> is_inside('foo.c', '')
-    False
-    >>> is_inside('', 'foo.c')
-    True
     """
     # XXX: Most callers of this can actually do something smarter by 
     # looking at the inventory
@@ -642,22 +643,8 @@
 ## decomposition (might be too tricksy though.)
 
 def splitpath(p):
-    """Turn string into list of parts.
-
-    >>> splitpath('a')
-    ['a']
-    >>> splitpath('a/b')
-    ['a', 'b']
-    >>> splitpath('a/./b')
-    ['a', 'b']
-    >>> splitpath('a/.b')
-    ['a', '.b']
-    >>> splitpath('a/../b')
-    Traceback (most recent call last):
-    ...
-    BzrError: sorry, '..' not allowed in path
-    """
-    assert isinstance(p, types.StringTypes)
+    """Turn string into list of parts."""
+    assert isinstance(p, basestring)
 
     # split on either delimiter because people might use either on
     # Windows
@@ -705,14 +692,14 @@
 def link_or_copy(src, dest):
     """Hardlink a file, or copy it if it can't be hardlinked."""
     if not hardlinks_good():
-        copyfile(src, dest)
+        shutil.copyfile(src, dest)
         return
     try:
         os.link(src, dest)
     except (OSError, IOError), e:
         if e.errno != errno.EXDEV:
             raise
-        copyfile(src, dest)
+        shutil.copyfile(src, dest)
 
 def delete_any(full_path):
     """Delete a file or directory."""
@@ -941,7 +928,7 @@
     lstat = os.lstat
     pending = []
     _directory = _directory_kind
-    _listdir = listdir
+    _listdir = os.listdir
     pending = [(prefix, "", _directory, None, top)]
     while pending:
         dirblock = []

=== modified file 'bzrlib/sign_my_commits.py'
--- bzrlib/sign_my_commits.py	2006-07-28 16:05:23 +0000
+++ bzrlib/sign_my_commits.py	2006-09-13 02:44:23 +0000
@@ -17,9 +17,15 @@
 """Command which looks for unsigned commits by the current user, and signs them.
 """
 
-from bzrlib import config, gpg
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from bzrlib import (
+    config,
+    gpg,
+    )
+from bzrlib.bzrdir import BzrDir
+""")
 from bzrlib.commands import Command
-from bzrlib.bzrdir import BzrDir
 from bzrlib.option import Option
 
 

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-09-12 20:46:42 +0000
+++ bzrlib/tests/__init__.py	2006-09-13 02:44:23 +0000
@@ -91,7 +91,6 @@
                       bzrlib.lockdir,
                       bzrlib.merge3,
                       bzrlib.option,
-                      bzrlib.osutils,
                       bzrlib.store
                       ]
 

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2006-09-05 13:57:30 +0000
+++ bzrlib/tests/test_osutils.py	2006-09-13 02:44:23 +0000
@@ -23,8 +23,11 @@
 import sys
 
 import bzrlib
+from bzrlib import (
+    errors,
+    osutils,
+    )
 from bzrlib.errors import BzrBadParameterNotUnicode, InvalidURL
-import bzrlib.osutils as osutils
 from bzrlib.tests import (
         StringIOWrapper,
         TestCase, 
@@ -78,6 +81,14 @@
         self.assertEqual(type(result), str)
         self.assertContainsRe(result, r'^[a-z0-9]{100}$')
 
+    def test_is_inside(self):
+        is_inside = osutils.is_inside
+        self.assertTrue(is_inside('src', 'src/foo.c'))
+        self.assertFalse(is_inside('src', 'srccontrol'))
+        self.assertTrue(is_inside('src', 'src/a/a/a/foo.c'))
+        self.assertTrue(is_inside('foo.c', 'foo.c'))
+        self.assertFalse(is_inside('foo.c', ''))
+        self.assertTrue(is_inside('', 'foo.c'))
 
     def test_rmtree(self):
         # Check to remove tree with read-only files/dirs
@@ -275,6 +286,18 @@
         except (IOError, OSError), e:
             self.assertEqual(errno.ENOENT, e.errno)
 
+    def test_splitpath(self):
+        def check(expected, path):
+            self.assertEqual(expected, osutils.splitpath(path))
+
+        check(['a'], 'a')
+        check(['a', 'b'], 'a/b')
+        check(['a', 'b'], 'a/./b')
+        check(['a', '.b'], 'a/.b')
+        check(['a', '.b'], 'a\\.b')
+
+        self.assertRaises(errors.BzrError, osutils.splitpath, 'a/../b')
+
 
 class TestMacFuncsDirs(TestCaseInTempDir):
     """Test mac special functions that require directories."""
@@ -300,6 +323,7 @@
         os.chdir(u'Ba\u030agfors')
         self.assertEndsWith(osutils._mac_getcwd(), u'B\xe5gfors')
 
+
 class TestSplitLines(TestCase):
 
     def test_split_unicode(self):

